@@ -1,8 +1,8 @@
-from itertools import chain
 from typing import Union, TypeVar, Sequence, List, Tuple, Iterable, Collection, Set
 
 import typing_inspect
 
+from injectable.autowiring.utils import sanitize_if_forward_ref, is_none_type
 from injectable.injection.inject import inject, inject_multiple
 
 T = TypeVar("T")
@@ -19,6 +19,23 @@ class _Autowired:
         lazy: bool = False,
     ):
         type_origin = typing_inspect.get_origin(dependency)
+        optional = False
+        multiple = False
+
+        if type_origin is Union:
+            subscripted_types = typing_inspect.get_args(dependency, evaluate=True)
+            if len(subscripted_types) == 0:
+                raise TypeError(f"Type not defined for Autowired Union")
+            if len(subscripted_types) != 2 or not is_none_type(subscripted_types[1]):
+                raise TypeError(
+                    f"Autowired Union can only be used to indicate"
+                    f" optional autowiring in the forms 'Union[T, None]' or"
+                    f" 'Optional[T]'"
+                )
+            dependency = sanitize_if_forward_ref(subscripted_types[0])
+            type_origin = typing_inspect.get_origin(dependency)
+            optional = True
+
         if type_origin in [
             list,
             tuple,
@@ -30,11 +47,18 @@ class _Autowired:
             Iterable,
             Collection,
         ]:
-            dependency = typing_inspect.get_args(dependency)
-            if len(dependency) == 0:
+            subscripted_types = typing_inspect.get_args(dependency)
+            if len(subscripted_types) == 0:
+                raise TypeError(f"Type not defined for Autowired {type_origin}")
+            if len(subscripted_types) > 1:
                 raise TypeError(
-                    f"Type not defined for Autowired {type_origin.__qualname__}"
+                    f"Only one type should be defined for Autowired {type_origin}"
                 )
+            dependency = sanitize_if_forward_ref(subscripted_types[0])
+            multiple = True
+
+        self.optional = optional
+        self.multiple = multiple
         self.dependency = dependency
         self.namespace = namespace
         self.group = group
@@ -42,18 +66,14 @@ class _Autowired:
         self.lazy = lazy
 
     def inject(self) -> T:
-        if type(self.dependency) is tuple:
-            return list(
-                chain.from_iterable(
-                    inject_multiple(
-                        dep,
-                        namespace=self.namespace,
-                        group=self.group,
-                        exclude_groups=self.exclude_groups,
-                        lazy=self.lazy,
-                    )
-                    for dep in self.dependency
-                )
+        if self.multiple:
+            return inject_multiple(
+                self.dependency,
+                namespace=self.namespace,
+                group=self.group,
+                exclude_groups=self.exclude_groups,
+                lazy=self.lazy,
+                optional=self.optional,
             )
         return inject(
             self.dependency,
@@ -61,6 +81,7 @@ class _Autowired:
             group=self.group,
             exclude_groups=self.exclude_groups,
             lazy=self.lazy,
+            optional=self.optional,
         )
 
 
@@ -77,7 +98,11 @@ class Autowired:
 
 
     :param dependency: class, base class or qualifier of the dependency to be used
-            for lookup among the registered injectables.
+            for lookup among the registered injectables. Can be wrapped in a typing
+            sequence, e.g. ``List[...]``, to inject a list containing all matching
+            injectables. Can be wrapped in a optional, e.g. ``Optional[...]``, to
+            inject None if no matches are found to inject. ``Optional[List[...]]`` is
+            valid and will inject an empty list if no matches are found to inject.
     :param namespace: (optional) namespace in which to look for the dependency.
             Defaults to the default namespace specified in
             :meth:`InjectionContainer::load <injectable.InjectionContainer.load>`
